.. include:: ../../README.rst

Contents:
=========

.. toctree::
   :maxdepth: 3

   usage
   configuration
   driver/index
   provider/index
   verifier
   bash
   development
   contributing
   changelog
   authors
   autodoc/index

.. _`Ansible`: https://docs.ansible.com
.. _`Test Kitchen`: http://kitchen.ci
.. _`playbook`: https://docs.ansible.com/ansible/playbooks.html
.. _`role`: http://docs.ansible.com/ansible/playbooks_roles.html
.. _`Serverspec`: http://serverspec.org
.. _`Testinfra`: https://testinfra.readthedocs.io
.. _`Vagrant`: http://docs.vagrantup.com/v2
.. _`Docker`: https://www.docker.com
.. _`OpenStack`: https://www.openstack.org
.. _`libvirt`: http://libvirt.org

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
